@@ -158,9 +158,6 @@ class BaseballReferenceScraper:
 
         html = requests.get(url)
 
-        if html.status_code == 502:
-        	raise URLError('502 Bad Gateway')
-
         return html.text
 
 # ------------------------------------------------------------------------
@@ -190,6 +187,10 @@ class BaseballReferenceScraper:
 
             # HAND / TYPE
             type = self.type(positional_fielding,year=year)
+
+            # WAR
+            stats_dict.update({'bWAR': self.__bWar(soup_for_homepage_stats, year, type)})
+
             # COVER THE CASE OF NOT HAVING DATA FOR A PARTICULAR YEAR (EX: JOHN SMOLTZ 2000)
             if not type:
                 continue
@@ -300,6 +301,7 @@ class BaseballReferenceScraper:
                     all_positions.update(position_dict)
 
         # GET DEFENSIVE WAR IN CASE OF LACK OF TZR AVAILABILITY FOR SEASONS < 1952
+        # UPDATE: SCRAPE TOTAL WAR AS WELL
         try:
             if is_full_career:
                 summarized_header = self.__get_career_totals_row(div_id='div_batting_value',soup_object=soup_for_homepage_stats)
@@ -307,7 +309,7 @@ class BaseballReferenceScraper:
                 dwar_object = summarized_header.find('td',attrs={'data-stat':'WAR_def'})
                 dwar_rating = float(dwar_object.get_text()) if dwar_object != None else 0
                 # USE AVG FOR CAREER
-                dwar_rating = dwar_rating / num_seasons 
+                dwar_rating = round(dwar_rating / num_seasons,2)
             else:
                 player_value = soup_for_homepage_stats.find('tr', attrs = {'id': 'batting_value.{}'.format(year)})
                 dwar_object = player_value.find('td',attrs={'class':'right','data-stat':'WAR_def'})
@@ -318,6 +320,36 @@ class BaseballReferenceScraper:
 
         return all_positions
 
+    def __bWar(self, soup_for_homepage_stats, year, type):
+        """Parse bWAR (baseball reference WAR)
+
+        Args:
+          soup_for_homepage_stats: BeautifulSoup object with all stats on homepage.
+          year: Year for Player stats
+          type: Pitcher or Hitter
+
+        Returns:
+          Float bWAR value
+        """
+        is_full_career = year == 'CAREER'
+        is_pitcher = type == 'Pitcher'
+        type_string = 'pitching' if is_pitcher else 'batting'
+        war_type_suffix = '_pitch' if is_pitcher else ''
+        try:
+            if is_full_career:
+                summarized_header = self.__get_career_totals_row(div_id=f"div_{type_string}_value",soup_object=soup_for_homepage_stats)
+                # TOTAL WAR
+                war_object = summarized_header.find('td',attrs={'data-stat':f"WAR{war_type_suffix}"})
+                war_rating = float(war_object.get_text()) if war_object != None else 0
+            else:
+                player_value = soup_for_homepage_stats.find('tr', attrs = {'id': f"{type_string}_value.{year}"})
+                # TOTAL WAR
+                war_object = player_value.find('td',attrs={'class':'right','data-stat':f"WAR{war_type_suffix}"})
+                war_rating = war_object.get_text() if war_object != None else 0
+            return war_rating
+        except:
+            return 0.0
+
     def hand(self, soup_for_homepage_stats, type):
         """Parse hand of player.
 
